<?php
/* $Id: serbian_latin-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */

/**
 * Translated by:
 *     Mihailo Stefanovic <mikis@users.sourceforge.net>, Branislav Jovanovic <fangorn@eunet.yu>
 *     Igor Mladenovic <mligor@zimco.com>, David Trajkovic <tdavid@ptt.yu>
 */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('bajtova', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Ned', 'Pon', 'Uto', 'Sre', 'Čet', 'Pet', 'Sub');
$month = array('jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'avg', 'sep', 'okt', 'nov', 'dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d. %B %Y. u %H:%M';
$timespanfmt = '%s dana, %s sati, %s minuta i %s sekundi';

$strAbortedClients = 'Prekinuto';
$strAccessDeniedExplanation = 'phpMyAdmin je pokušao da se poveže na MySQL server, ali je server odbio povezivanje. Proverite naziv domaćina, korisničko ime i lozinku u config.inc.php i uverite se da odgovaraju podacima koje ste dobili od administratora MySQL servera.';
$strAccessDenied = 'Pristup odbijen';
$strAction = 'Akcija';
$strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrednost';
$strAddConstraints = 'Dodaj ograničenja';
$strAddDeleteColumn = 'Dodaj/obriši kolonu';
$strAddDeleteRow = 'Dodaj/obriši polje za kriterijum';
$strAddFields = 'Dodaj %s polja';
$strAddHeaderComment = 'Dodaj komentar u zaglavlje (\\n razdvaja linije)';
$strAddIntoComments = 'Dodaj u komentare';
$strAddNewField = 'Dodaj novo polje';
$strAddPrivilegesOnDb = 'Dodaj privilegije na sledećoj bazi';
$strAddPrivilegesOnTbl = 'Dodaj privilegije na sledećoj tabeli';
$strAddSearchConditions = 'Dodaj uslove pretraživanja (deo "WHERE" upita):';
$strAddToIndex = 'Dodaj u ključ &nbsp;%s&nbsp;kolona(e)';
$strAddUser = 'Dodaj novog korisnika';
$strAddUserMessage = 'Dodali ste novog korisnika.';
$strAdministration = 'Administracija';
$strAffectedRows = 'Obuhvaćeno redova:';
$strAfterInsertBack = 'Nazad na prethodnu stranu';
$strAfterInsertNewInsert = 'Dodaj još jedan novi red';
$strAfterInsertNext = 'Uredi sledeći red';
$strAfterInsertSame = 'Vrati se na ovu stranu';
$strAfter = 'Posle %s';
$strAll = 'Sve';
$strAllTableSameWidth = 'Prikaz svih tabela iste širine?';
$strAlterOrderBy = 'Promeni redosled u tabeli';
$strAnalyzeTable = 'Analiziraj tabelu';
$strAnd = 'i';
$strAndThen = 'i onda';
$strAnIndex = 'Ključ je upravo dodat %s';
$strAny = 'Bilo koji';
$strAnyHost = 'Bilo koji domaćin';
$strAnyUser = 'Bilo koji korisnik';
$strApproximateCount = 'Može biti približno. Vidite FAQ 3.11';
$strAPrimaryKey = 'Primarni ključ je upravo dodat %s';
$strArabic = 'Arapski';
$strArmenian = 'Jermenski';
$strAscending = 'Rastući';
$strAtBeginningOfTable = 'Na početku tabele';
$strAtEndOfTable = 'Na kraju tabele';
$strAttr = 'Atributi';
$strAutomaticLayout = 'Automatski raspored';

$strBack = 'Nazad';
$strBaltic = 'Baltički';
$strBeginCut = 'POČETAK REZ';
$strBeginRaw = 'POČETAK SIROVO';
$strBinary = 'Binarni';
$strBinaryDoNotEdit = 'Binarni - ne menjaj';
$strBinaryLog = 'Binarni dnevnik';
$strBinLogEventType = 'Vrsta događaja';
$strBinLogInfo = 'Informacije';
$strBinLogName = 'Naziv dnevnika';
$strBinLogOriginalPosition = 'Originalna pozicija';
$strBinLogPosition = 'Pozicija';
$strBinLogServerId = 'ID servera';
$strBookmarkAllUsers = 'Dozvoli svakom korisniku da pristupa ovom zapamćenom upitu';
$strBookmarkDeleted = 'Obeleživač je upravo obrisan.';
$strBookmarkLabel = 'Naziv';
$strBookmarkQuery = 'Zapamćen SQL-upit';
$strBookmarkThis = 'Zapamti SQL-upit';
$strBookmarkView = 'Vidi samo';
$strBrowseForeignValues = 'Pregledaj strane vrednosti';
$strBrowse = 'Pregled';
$strBufferPoolActivity = 'Aktivnost skupa prihvatnika';
$strBufferPool = 'Skup prihvatnika';
$strBufferPoolUsage = 'Korišćenje skupa prihvatnika';
$strBufferReadMissesInPercent = 'Promašaji čitanja u %';
$strBufferReadMisses = 'Promašaji pri čitanju';
$strBufferWriteWaits = 'Čekanja na upis';
$strBufferWriteWaitsInPercent = 'Čekanja na upis u %';
$strBulgarian = 'Bugarski';
$strBusyPages = 'Zauzete strane';
$strBzError = 'phpMyAdmin nije mogao da kompresuje sadržaj baze zbog neispravne BZ2 ekstenzije u ovoj verziji PHP-a. Preporučuje se da podesite <code>$cfg[\'BZipDump\']</code> direktivu u vašoj phpMyAdmin konfiguracionoj datoteci na <code>FALSE</code>. Ako želite da koristite mogućnosti BZ2 kompresije, trebalo bi da pređete na noviju verziju PHP-a. Vidite PHP izveštaj o greškama %s za detalje.';
$strBzip = '"bzip-ovano"';

$strCalendar = 'Kalendar';
$strCannotLogin = 'Ne mogu da se prijavim na MySQL server';
$strCantLoad = 'ne mogu da učitam ekstenziju %s,<br />molim proverite PHP konfiguraciju';
$strCantLoadRecodeIconv = 'Ne mogu da učitam iconv ili recode ekstenzije potrebne za konverziju skupova znakova, podesite PHP da dozvoli korišćenje ovih ekstenzija ili onemogućite konverziju skupova znakova u phpMyAdmin-u.';
$strCantRenameIdxToPrimary = 'Ne mogu da promenim ključ u PRIMARY (primarni) !';
$strCantUseRecodeIconv = 'Ne mogu da koristim iconv ili libiconv ili recode_string funkcije iako ekstenzija prijavljuje da je učitana. Proverite vašu PHP konfiguraciju.';
$strCardinality = 'Kardinalnost';
$strCaseInsensitive = 'Ne razlikuje mala i velika slova';
$strCaseSensitive = 'Razlikuje mala i velika slova';
$strCentralEuropean = 'Centralnoevropski';
$strChangeCopyModeCopy = '... sačuvaj stare.';
$strChangeCopyModeDeleteAndReload = ' ... obriši starog iz tabele korisnika i zatim ponovo učitaj privilegije.';
$strChangeCopyModeJustDelete = ' ... obriši stare iz tabela korisnika.';
$strChangeCopyMode = 'Napravi novog korisnika sa istim privilegijama i ...';
$strChangeCopyModeRevoke = ' ... obustavi sve privilegije starog korisnika i zatim ga obriši.';
$strChangeCopyUser = 'Promeni informacije o prijavi / Kopiraj korisnika';
$strChangeDisplay = 'Izaberi polja za prikaz';
$strChangePassword = 'Promeni lozinku';
$strChange = 'Promeni';
$strCharset = 'Karakter set';
$strCharsetOfFile = 'Karakter set datoteke:';
$strCharsetsAndCollations = 'Karakter setovi i sortiranje';
$strCharsets = 'Kodne strane';
$strCheckAll = 'Označi sve';
$strCheckOverhead = 'Proveri prekoračenja';
$strCheckPrivsLong = 'Proveri privilegije za bazu &quot;%s&quot;.';
$strCheckPrivs = 'Proveri privilegije';
$strCheckTable = 'Proveri tabelu';
$strChoosePage = 'Izaberite stranu koju menjate';
$strColComFeat = 'Prikazujem komentare kolone';
$strCollation = 'Sortiranje';
$strColumnNames = 'Imena kolona';
$strColumnPrivileges = 'Privilegije vezane za kolone';
$strCommand = 'Naredba';
$strCommentsForTable = 'KOMENTARI TABELE';
$strComments = 'Komentari';
$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibilno';
$strCompleteInserts = 'Kompletan INSERT (sa imenima polja)';
$strCompression = 'Kompresija';
$strConfigFileError = 'phpMyAdmin nije mogao da pročita vašu konfiguracionu datoteku!<br />Ovo se može desiti ako PHP nađe grešku u procesiranju ili ne može da pronađe datoteku.<br />Pozovite konfiguracionu datoteku direktno koristeći donji link i pročitajte poruke o grešci koje dobijate. U većini slučajeve negde nedostaje navodnik ili tačka-zarez.<br />Ako dobijete praznu stranu, sve je u redu.';
$strConfigureTableCoord = 'Podesite koordinate za tabelu %s';
$strConnectionError = 'Ne mogu da se povežem: neispravna podešavanja.';
$strConnections = 'Konekcije';
$strConstraintsForDumped = 'Ograničenja za izvezene tabele';
$strConstraintsForTable = 'Ograničenja za tabele';
$strCookiesRequired = 'Kolačići (Cookies) moraju u ovom slučaju biti aktivni.';
$strCopyDatabaseOK = 'Baza %s je prekopirana u %s';
$strCopy = 'Kopiraj';
$strCopyTable = 'Kopiraj tabelu u (baza<b>.</b>tabela):';
$strCopyTableOK = 'Tabela %s je kopirana u %s.';
$strCopyTableSameNames = 'Ne mogu da kopiram tabelu u samu sebe!';
$strCouldNotKill = 'phpMyAdmin nije mogao da prekine proces %s. Verovatno je već zatvoren.';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE pre kopiranja';
$strCreateIndex = 'Napravi ključ na&nbsp;%s&nbsp;kolona';
$strCreateIndexTopic = 'Napravi novi ključ';
$strCreate = 'Napravi';
$strCreateNewDatabase = 'Napravi novu bazu podataka';
$strCreateNewTable = 'Napravi novu tabelu u bazi %s';
$strCreatePage = 'Napravi novu stranu';
$strCreatePdfFeat = 'Pravljenje PDF-ova';
$strCreationDates = 'Datumi kreiranja/ažuriranja/provere';
$strCriteria = 'Kriterijum';
$strCroatian = 'Hrvatski';
$strCyrillic = 'Ćirilični';
$strCzech = 'Češki';
$strCzechSlovak = 'Češko-slovački';

$strDanish = 'Danski';
$strDatabase = 'Baza podataka';
$strDatabaseEmpty = 'Ime baze nije zadato!';
$strDatabaseExportOptions = 'Opcije za izvoz baze';
$strDatabaseHasBeenDropped = 'Baza %s je odbačena.';
$strDatabases = 'Baze';
$strDatabasesDropped = '%s baza je uspešno odbačeno.';
$strDatabasesStatsDisable = 'Isključi statistike';
$strDatabasesStatsEnable = 'Uključi statistike';
$strDatabasesStatsHeavyTraffic = 'Napomena: uključivanje statistika može prouzrokovati veliki saobraćaj između veb i MySQL servera.';
$strDatabasesStats = 'Statistika baze';
$strDataDict = 'Rečnik podataka';
$strDataOnly = 'Samo podaci';
$strDataPages = 'Strane sa podacima';
$strData = 'Podaci';
$strDBComment = 'Komentar baze:';
$strDBCopy = 'Kopiraj bazu u';
$strDbPrivileges = 'Privilegije vezane za bazu';
$strDBRename = 'Preimenuj bazu u';
$strDbSpecific = 'Specifično za bazu';
$strDefaultEngine = '%s je podrazumevani pogon skladištenja na ovom MySQL serveru.';
$strDefault = 'Podrazumevano';
$strDefaultValueHelp = 'Za podrazumevanu vrednost, unesite samo jednu vrednost, bez kosih crta ili navodnika u ovom obliku: a';
$strDefragment = 'Defragmentiraj tabelu';
$strDelayedInserts = 'Koristi odložena umetanja';
$strDeleteAndFlushDescr = 'Ovo je najčistiji način, ali ponovno učitavanje privilegina može da potraje.';
$strDeleteAndFlush = 'Obriši korisnike i ponovo učitaj privilegije.';
$strDeleted = 'Red je obrisan';
$strDeletedRows = 'Obrisani redovi:';
$strDelete = 'Obriši';
$strDeleting = 'Brišem %s';
$strDelOld = 'Trenutna strana ima reference na tabele koje više ne postoje. Želite li da obrišete te reference?';
$strDescending = 'Opadajući';
$strDescription = 'Opis';
$strDictionary = 'rečnik';
$strDirtyPages = 'Prljave strane';
$strDisabled = 'Onemogućeno';
$strDisableForeignChecks = 'Isključi provere stranih ključeva';
$strDisplayFeat = 'Prikaži osobine';
$strDisplayOrder = 'Redosled prikaza:';
$strDisplayPDF = 'Prikaži PDF shemu';
$strDoAQuery = 'Napravi "upit po primeru" (džoker: "%")';
$strDocu = 'Dokumentacija';
$strDoYouReally = 'Da li stvarno hoćete da ';
$strDropDatabaseStrongWarning = 'Ovim ćete UNIŠTITI kompletnu bazu podataka!';
$strDrop = 'Odbaci';
$strDropUsersDb = 'Odbaci baze koje se zovu isto kao korisnici.';
$strDumpingData = 'Prikaz podataka tabele';
$strDumpSaved = 'Sadržaj baze je sačuvan u datoteku %s.';
$strDumpXRows = 'Prikaži %s redova počevši od reda %s.';
$strDynamic = 'dinamički';

$strEditPDFPages = 'Uređivanje PDF strana';
$strEditPrivileges = 'Promeni privilegije';
$strEdit = 'Promeni';
$strEffective = 'Efektivne';
$strEmpty = 'Isprazni';
$strEmptyResultSet = 'MySQL je vratio prazan rezultat (nula redova).';
$strEnabled = 'Omogućeno';
$strEncloseInTransaction = 'Obavi izvoz u transakciji';
$strEndCut = 'KRAJ REZ';
$strEnd = 'Kraj';
$strEndRaw = 'KRAJ SIROVO';
$strEngineAvailable = '%s je dostupan na ovom MySQL serveru.';
$strEngineDisabled = '%s je onemogućen na ovom MySQL serveru.';
$strEngines = 'Skladištenja';
$strEngineUnsupported = 'Ovaj MySQL server ne podržava %s pogon skladištenja.';
$strEnglish = 'Engleski';
$strEnglishPrivileges = ' Napomena: MySQL imena privilegija moraju da budu na engleskom ';
$strError = 'Greška';
$strEscapeWildcards = 'Pre džokera _ i % treba staviti znak \ ako ih koristite samostalno';
$strEstonian = 'Estonski';
$strExcelEdition = 'Excel izdanje';
$strExecuteBookmarked = 'Izvrši upamćen upit';
$strExplain = 'Objasni SQL';
$strExport = 'Izvoz';
$strExtendedInserts = 'Prošireni INSERT';
$strExtra = 'Dodatno';

$strFailedAttempts = 'Neuspelih pokušaja';
$strFieldHasBeenDropped = 'Polje %s je obrisano';
$strField = 'Polje';
$strFieldsEnclosedBy = 'Polja ograničena sa';
$strFieldsEscapedBy = 'Escape karakter &nbsp; &nbsp; &nbsp;';
$strFields = 'Polja';
$strFieldsTerminatedBy = 'Polja razdvojena sa';
$strFileAlreadyExists = 'Datoteka %s već postoji na serveru, promenite ime datoteke ili uključite opciju prepisivanja.';
$strFileCouldNotBeRead = 'Datoteku nije moguće pročitati';
$strFileNameTemplateRemember = 'zapamti šablon';
$strFileNameTemplate = 'Šablon imena datoteke';
$strFixed = 'sređeno';
$strFlushPrivilegesNote = 'Napomena: phpMyAdmin uzima privilegije korisnika direktno iz MySQL tabela privilegija. Sadržaj ove tabele može se razlikovati od privilegija koje server koristi ako su vršene ručne izmene. U tom slučaju %sponovo učitajte privilegije%s pre nego što nastavite.';
$strFlushTable = 'Osveži tabelu ("FLUSH")';
$strFormat = 'Format';
$strFormEmpty = 'Nedostaje vrednost u obrascu!';
$strFreePages = 'Slobodne strane';
$strFullText = 'Pun tekst';
$strFunction = 'Funkcija';

$strGenBy = 'Generisao';
$strGeneralRelationFeat = 'Opšte osobine relacija';
$strGenerate = 'Napravi';
$strGeneratePassword = 'Napravi lozinku';
$strGenTime = 'Vreme kreiranja';
$strGeorgian = 'Gruzijski';
$strGerman = 'Nemački';
$strGlobal = 'globalno';
$strGlobalPrivileges = 'Globalne privilegije';
$strGlobalValue = 'Globalna vrednost';
$strGo = 'Kreni';
$strGrantOption = 'Omogući';
$strGreek = 'Grčki';
$strGzip = '"gzip-ovano"';

$strHasBeenAltered = 'je promenjen(a).';
$strHasBeenCreated = 'je kreiran(a).';
$strHaveToShow = 'Morate izabrati bar jednu kolonu za prikaz';
$strHebrew = 'Hebrejski';
$strHomepageOfficial = 'phpMyAdmin veb sajt';
$strHome = 'Početna strana';
$strHost = 'Domaćin';
$strHostEmpty = 'Ime domaćina je prazno!';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHungarian = 'Mađarski';

$strIcelandic = 'Islandski';
$strId = 'ID';
$strIdxFulltext = 'Tekst ključ';
$strIgnore = 'Ignoriši';
$strIgnoreInserts = 'Ignoriši duplikate pri umetanju';
$strImportFiles = 'Uvoz datoteka';
$strIndexes = 'Ključevi';
$strIndexHasBeenDropped = 'Ključ %s je obrisan';
$strIndex = 'Ključ';
$strIndexName = 'Ime ključa :';
$strIndexType = 'Tip ključa :';
$strIndexWarningTable = 'Problem pri indeksiranju tabele `%s`';
$strInnoDBAutoextendIncrementDesc = ' Veličina koraka proširenja veličine tabela koje se automatski proširuju kada se napune.';
$strInnoDBAutoextendIncrement = 'Korak automatskog proširenja';
$strInnoDBBufferPoolSizeDesc = 'Veličina memorijskog prihvatnika koje InnoDB koristi za keširanje podataka i indeksa svojih tabela.';
$strInnoDBBufferPoolSize = 'Veličina prihvatnika';
$strInnoDBDataFilePath = 'Datoteke sa podacima';
$strInnoDBDataHomeDirDesc = 'Zajednički deo putanje direktorijuma za sve InnoDB datoteke sa podacima.';
$strInnoDBDataHomeDir = 'Osnovni direktorijum podataka';
$strInnoDBPages = 'strana';
$strInnodbStat = 'InnoDB status';
$strInsecureMySQL = 'Vaša konfiguraciona datoteka sadrži podešavanja (root bez lozinke) koja odgovaraju standardnom MySQL privilegovanom nalogu. Vaš MySQL server radi sa ovim podešavanjima, otvoren je za upade, i zaista treba da ispravite ovaj sigurnosni rizik.';
$strInsertAsNewRow = 'Unesi kao novi red';
$strInsertedRowId = 'ID umetnutih redova:';
$strInsertedRows = 'Uneseno redova:';
$strInsert = 'Novi zapis';
$strInternalNotNecessary = '* Unutrašnja relacija nije neophodna kada postoji i u InnoDB.';
$strInternalRelations = 'Unutrašnje relacije';
$strInUse = 'se koristi';
$strInvalidColumnCount = 'Broj kolona mora biti veći od nule.';
$strInvalidFieldAddCount = 'Morate dodati barem jedno polje.';
$strInvalidFieldCount = 'Tabela mora imati barem jedno polje.';
$strInvalidRowNumber = '%d nije ispravan broj reda.';

$strJapanese = 'Japanski';
$strJumpToDB = 'Pređi na bazu &quot;%s&quot;.';
$strJustDeleteDescr = '&quot;Obrisani&quot; korisnici će i dalje imati pristup serveru dok privilegije ne budu ponovo učitane.';
$strJustDelete = 'Samo obriši korisnike iz tabele privilegija.';

$strKeepPass = 'Nemoj da menjaš lozinku';
$strKeyname = 'Ime ključa';
$strKill = 'Obustavi';
$strKorean = 'Korejski';

$strLandscape = 'Položeno';
$strLatchedPages = 'Zabravljene strane';
$strLatexCaption = 'Komentar tabele';
$strLatexContent = 'Sadržaj tabele __TABLE__';
$strLatexContinuedCaption = 'Nastavljen komentar tabele';
$strLatexContinued = '(nastavljeno)';
$strLatexIncludeCaption = 'Uključi komentar tabele';
$strLatexLabel = 'Oznaka ključa';
$strLaTeX = 'LaTeX';
$strLatexStructure = 'Struktura tabele __TABLE__';
$strLatvian = 'Letonski';
$strLengthSet = 'Dužina/Vrednost*';
$strLimitNumRows = 'Broj redova po strani';
$strLinesTerminatedBy = 'Linije se završavaju sa';
$strLinkNotFound = 'Veza nije pronađena';
$strLinksTo = 'Veze ka';
$strLithuanian = 'Litvanski';
$strLocalhost = 'Lokalni';
$strLocationTextfile = 'Lokacija tekstualne datoteke';
$strLoginInformation = 'Podaci o prijavi';
$strLogin = 'Prijavljivanje';
$strLogout = 'Odjavljivanje';
$strLogPassword = 'Lozinka:';
$strLogServer = 'Server';
$strLogUsername = 'Korisničko ime:';
$strLongOperation = 'Ova operacija može da potraje. Da li da nastavimo?';

$strMaximumSize = 'Maksimalna veličina: %s%s';
$strMbExtensionMissing = 'mbstring PHP ekstenzija nije pronađena, a čini se da vi koristite višebajtni skup znakova. Bez mbstring ekstenzije phpMyAdmin ne može ispravno da razdvaja stringove i to može dovesti do neočekivanih rezultata.';
$strMbOverloadWarning = 'Uključena vam je mbstring.func_overload opcija u PHP podešavanjima. Ova opcija je nekompatibilna sa phpMyAdmin i može dovesti do grešaka u nekim podacima!';
$strMIME_available_mime = 'Dostupni MIME-tipovi';
$strMIME_available_transform = 'Dostupne transformacije';
$strMIME_description = 'Opis';
$strMIME_MIMEtype = 'MIME-tipovi';
$strMIME_nodescription = 'Nema opisa za ovu transformaciju.<br />Molimo pitajte autora šta %s radi.';
$strMIME_transformation_note = 'Za listu dostupnih opcija transformacije i njihove transformacije MIME-tipova, kliknite na %sopise transformacija%s';
$strMIME_transformation_options_note = 'Molimo unesite vrednosti za opcije transformacije koristeći ovaj oblik: \'a\', 100, b,\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrednosti, stavite obrnutu kosu crtu ispred njih (na primer \'\\\\xyz\' ili \'a\\\'b\').';
$strMIME_transformation_options = 'Opcije transformacije';
$strMIME_transformation = 'Tranformacije čitača';
$strMIMETypesForTable = 'MIME TIPOVI ZA TABELU';
$strMIME_without = 'MIME-tipovi prikazani u kurzivu nemaju odvojene funkcije transformacije.';
$strModifications = 'Izmene su sačuvane';
$strModifyIndexTopic = 'Izmeni ključ';
$strModify = 'Promeni';
$strMoveTableOK = 'Tabela %s je pomerena u %s.';
$strMoveTable = 'Pomeri tabelu u (baza<b>.</b>tabela):';
$strMoveTableSameNames = 'Ne mogu da premestim tabelu u samu sebe!';
$strMultilingual = 'višejezički';
$strMyISAMDataPointerSizeDesc = 'Podrazumevana veličina pokazivača u bajtovima, koristi se pri CREATE TABLE za MyISAM tabele kada nije zadata opcija MAX_ROWS';
$strMyISAMDataPointerSize = 'Veličina pokazivača podataka';
$strMyISAMMaxExtraSortFileSizeDesc = 'Ako bi privremena datoteka koja se koristi za brzo kreiranje MyISAM indeksa bila veća nego pri korišćenju keša ključeva za ovde zadatu vrednost, koristi metod keširanja ključeva';
$strMyISAMMaxExtraSortFileSize = 'Maksimalna veličina privremenih datoteka pri kreiranju indeksa';
$strMyISAMMaxSortFileSizeDesc = 'Maksimalna veličina privremenih datoteka koje MySQL sme da koristi pri re-kreiranju MyISAM indeksa (u toku REPAIR TABLE, ALTER TABLE, ili LOAD DATA INFILE operacija).';
$strMyISAMMaxSortFileSize = 'Maksimalna veličina privremenih datoteka za sortiranje';
$strMyISAMRecoverOptionsDesc = 'Režim automatskog oporavka puknutih MyISAM tabela, podešen pri startovanju servera opcijom --myisam-recover.';
$strMyISAMRecoverOptions = 'Režim automatskog oporavka';
$strMyISAMRepairThreadsDesc = 'Ako je vrednost veća od 1, indeksi MyISAM tabela se paralelno kreiraju (svaki indeks u sopstvenoj niti) za vreme procesa popravke sortiranjem.';
$strMyISAMRepairThreads = 'Niti popravke';
$strMyISAMSortBufferSizeDesc = 'Prihvatnik koji se alocira pri sortiranju MyISAM indeksa za vreme operacije REPAIR TABLE ili pri kreiranju indeksa sa CREATE INDEX ili ALTER TABLE.';
$strMyISAMSortBufferSize = 'Veličina prihvatnika za sortiranje';
$strMySQLCharset = 'MySQL set karaktera';
$strMySQLConnectionCollation = 'Sortiranje za MySQL vezu';
$strMySQLSaid = 'MySQL reče: ';
$strMySQLShowProcess = 'Prikaži listu procesa';
$strMySQLShowStatus = 'Prikaži MySQL informacije o toku rada';
$strMySQLShowVars = 'Prikaži MySQL sistemske promenljive';

$strName = 'Ime';
$strNext = 'Sledeći';
$strNoActivity = 'Nije bilo aktivnosti %s ili više sekundi, molimo prijavite se ponovo';
$strNoDatabases = 'Baza ne postoji';
$strNoDatabasesSelected = 'Nije izabrana ni jedna baza.';
$strNoDescription = 'nema opisa';
$strNoDetailsForEngine = 'Nema detaljnijih informacija o statusu za ovaj pogon skladištenja.';
$strNoDropDatabases = '"DROP DATABASE" komanda je onemogućena.';
$strNoExplain = 'Preskoči objašnjavanje SQL-a';
$strNoFrames = 'phpMyAdmin preferira čitače koji podržavaju okvire.';
$strNoIndex = 'Ključ nije definisan!';
$strNoIndexPartsDefined = 'Delovi ključa nisu definisani!';
$strNoModification = 'Nema izmena';
$strNo = 'Ne';
$strNone = 'nema';
$strNoOptions = 'Ne postoje opcije za ovaj format';
$strNoPassword = 'Nema lozinke';
$strNoPermission = 'Veb serveru nije dozvoljeno da sačuva datoteku %s.';
$strNoPhp = 'bez PHP koda';
$strNoPrivileges = 'Nema privilegija';
$strNoRights = 'Nije Vam dozvoljeno da budete ovde!';
$strNoRowsSelected = 'Nema odabranih redova';
$strNoSpace = 'Nedovoljno prostora za snimanje datoteke %s.';
$strNoTablesFound = 'Tabele nisu pronađene u bazi.';
$strNoThemeSupport = 'Nema podrške za teme, molimo proverite konfiguraciju i/ili teme u direktorijumu %s.';
$strNotNumber = 'Ovo nije broj!';
$strNotOK = 'nije u redu';
$strNotSet = '<b>%s</b> tabela nije pronađena ili nije postavljena u %s';
$strNoUsersFound = 'Korisnik nije nađen.';
$strNoValidateSQL = 'Preskoči proveru SQL-a';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s pogodaka unutar tabele <i>%s</i>';
$strNumSearchResultsTotal = '<b>Ukupno:</b> <i>%s</i> pogodaka';
$strNumTables = 'Tabele';

$strOK = 'U redu';
$strOperations = 'Operacije';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimizuj tabelu';
$strOr = 'ili';
$strOverhead = 'Prekoračenje';
$strOverwriteExisting = 'Prepiši postojeće datoteke';

$strPageNumber = 'Broj strane:';
$strPagesToBeFlushed = 'Strane koje treba da budu usklađene';
$strPaperSize = 'Dimenzije papira';
$strPartialText = 'Deo teksta';
$strPasswordChanged = 'Lozinka za %s je uspešno promenjena.';
$strPasswordEmpty = 'Lozinka je prazna!';
$strPasswordHashing = 'Heširanje lozinke';
$strPassword = 'Lozinka';
$strPasswordNotSame = 'Lozinke nisu identične!';
$strPdfDbSchema = 'Shema baze "%s" - Strana %s';
$strPdfInvalidTblName = 'Tabela "%s" ne postoji!';
$strPdfNoTables = 'Nema tabela';
$strPerHour = 'na sat';
$strPerMinute = 'u minutu';
$strPerSecond = 'u sekundi';
$strPersian = 'Persijski';
$strPhoneBook = 'telefonski imenik';
$strPHP40203 = 'Koristite PHP 4.2.3, koji ima ozbiljan bag sa višebajtnim stringovima (mbstring). Pogledajte izveštaj o grešci br. 19404. Ova verzija PHP-a se ne preporučuje za korišćenje sa phpMyAdmin.';
$strPhp = 'Napravi PHP kod';
$strPHPVersion = 'verzija PHP-a';
$strPmaDocumentation = 'phpMyAdmin dokumentacija';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktiva MORA biti podešena u konfiguracionoj datoteci!';
$strPolish = 'Poljski';
$strPortrait = 'Uspravno';
$strPos1 = 'Početak';
$strPrevious = 'Prethodna';
$strPrimaryKeyHasBeenDropped = 'Primarni ključ je obrisan';
$strPrimaryKeyName = 'Ime primarnog ključa mora da bude... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>mora</b> biti ime <b>samo</b> primarnog ključa!)';
$strPrimary = 'Primarni';
$strPrint = 'Štampaj';
$strPrintViewFull = 'Pogled za štampu (sa punim tekstom)';
$strPrintView = 'Za štampu';
$strPrivDescAllPrivileges = 'Uključuje sve privilegije osim GRANT.';
$strPrivDescAlter = 'Dozvoljava izmenu struktura postojećih tabela.';
$strPrivDescAlterRoutine = 'Dozvoljava izmenu i odbacivanje sačuvanih rutina.';
$strPrivDescCreateDb = 'Dozvoljava kreiranje novih baza i tabela.';
$strPrivDescCreateRoutine = 'Dozvoljava pravljenje sačuvanih rutina.';
$strPrivDescCreateTbl = 'Dozvoljava kreiranje novih tabela.';
$strPrivDescCreateTmpTable = 'Dozvoljava kreiranje privremenih tabela..';
$strPrivDescCreateUser = 'Dozvoljava pravljenje, odbacivanje i preimenovanje korisničkih naloga.';
$strPrivDescCreateView = 'Dozvoli kreiranje novih pogleda.';
$strPrivDescDelete = 'Dozvoljava brisanje podataka.';
$strPrivDescDropDb = 'Dozvoljava odbacivanje baza i tabela.';
$strPrivDescDropTbl = 'Dozvoljava odbacivanje tabela.';
$strPrivDescExecute5 = 'Dozvoljava izvršavanje sačuvanih rutina.';
$strPrivDescExecute = 'Dozvoljava pokretanje sačuvanih procedura. Nema efekta u ovoj verziji MySQL-a.';
$strPrivDescFile = 'Dozvoljava uvoz podataka i njihov izvoz u datoteke.';
$strPrivDescGrant = 'Dozvoljava dodavanje korisnika i privilegija bez ponovnog učitavanja tabela privilegija.';
$strPrivDescIndex = 'Dozvoljava kreiranje i brisanje ključeva.';
$strPrivDescInsert = 'Dozvoljava umetanje i zamenu podataka.';
$strPrivDescLockTables = 'Dozvoljava zaključavanje tabela tekućim procesima.';
$strPrivDescMaxConnections = 'Ograničava broj novih konekcija koje korisnik može ta otvori na sat.';
$strPrivDescMaxQuestions = 'Ograničava broj upita koje korisnik može da uputi serveru za sat.';
$strPrivDescMaxUpdates = 'Ograničava broj komandi koje menjaju tabele ili baze koje korisnik može da izvrši na sat.';
$strPrivDescProcess3 = 'Dozvoljava prekidanje procesa drugih korisnika.';
$strPrivDescProcess4 = 'Dozvoljava pregled kompletnih upita u listi procesa.';
$strPrivDescReferences = 'Nema efekta u ovoj verziji MySQL-a.';
$strPrivDescReload = 'Dozvoljava ponovno učitavanje podešavanja servera i pražnjenje keša servera.';
$strPrivDescReplClient = 'Daje pravo korisniku da pita gde su glavni/pomoćni serveri.';
$strPrivDescReplSlave = 'Potrebno zbog pomoćnih servera za replikaciju.';
$strPrivDescSelect = 'Dozvoljava čitanje podataka.';
$strPrivDescShowDb = 'Daje pristup kompletnoj listi baza.';
$strPrivDescShowView = 'Dozvoljava izvršavanje SHOW CREATE VIEW upita.';
$strPrivDescShutdown = 'Dozvoljava gašenje servera.';
$strPrivDescSuper = ' Dozvoljava povezivanje iako je dostignut maksimalan broj dozvoljenih veza; Neophodno za većinu administrativnih opcija kao što su podešavanje globalnih promenljivih ili prekidanje procesa ostalih korisnika.';
$strPrivDescUpdate = 'Dozvoljava izmenu podataka.';
$strPrivDescUsage = 'Nema privilegija.';
$strPrivileges = 'Privilegije';
$strPrivilegesReloaded = 'Privilegije su uspešno ponovo učitane.';
$strProcesses = 'Procesi';
$strProcesslist = 'Lista procesa';
$strPutColNames = 'Stavi imena polja u prvi red';

$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQBE = 'Upit po primeru';
$strQueryFrame = 'Prozor za upite';
$strQueryOnDb = 'SQL upit na bazi <b>%s</b>:';
$strQuerySQLHistory = 'SQL istorijat';
$strQueryStatistics = '<b>Statistike upita</b>: %s upita je postavljeno serveru od njegovog pokretanja.';
$strQueryTime = 'Upit je trajao %01.4f sekundi';
$strQueryType = 'Vrsta upita';
$strQueryWindowLock = 'Ne prepisuj ovaj upit izvan prozora';

$strReadRequests = 'Zahtevi za čitanje';
$strReceived = 'Primljeno';
$strRecords = 'Zapisi';
$strReferentialIntegrity = 'Proveri referencijalni integritet:';
$strRefresh = 'Osveži';
$strRelationalSchema = 'Relaciona shema';
$strRelationNotWorking = 'Dodatne mogućnosti za rad sa povezanim tabelama su isključene. Da biste saznali zašto, kliknite %sovde%s.';
$strRelationsForTable = 'RELACIJE TABELE';
$strRelations = 'Relacije';
$strRelationView = 'Relacioni pogled';
$strReloadingThePrivileges = 'Ponovo učitavam privilegije';
$strRemoveSelectedUsers = 'Ukloni izabrane korisnike';
$strRenameDatabaseOK = 'Baza %s je preimenovana u %s';
$strRenameTableOK = 'Tabeli %s promenjeno ime u %s';
$strRenameTable = 'Promeni ime tabele u ';
$strRepairTable = 'Popravi tabelu';
$strReplaceNULLBy = 'Zameni NULL sa';
$strReplaceTable = 'Zameni podatke u tabeli sa podacima iz datoteke';
$strReset = 'Poništi';
$strResourceLimits = 'Ograničenja resursa';
$strReType = 'Ponovite unos';
$strRevokeAndDeleteDescr = 'Korisnici će i dalje imati USAGE privilegije dok se privilegije ponovo ne učitaju.';
$strRevokeAndDelete = 'Obustavi sve aktivne privilegije korisnika i zatim ih obriši.';
$strRevokeMessage = 'Zabranili ste privilegije za %s';
$strRevoke = 'Zabrani';
$strRomanian = 'Rumunski';
$strRowLength = 'Dužina reda';
$strRowsFrom = ' redova počev od reda';
$strRowSize = 'Veličina reda';
$strRowsModeFlippedHorizontal = 'horizontalnom (rotirana zaglavlja)';
$strRowsModeHorizontal = 'horizontalnom';
$strRowsModeOptions = 'u %s modu i ponovi zaglavlje posle svakog %s reda';
$strRowsModeVertical = 'vertikalnom';
$strRows = 'Redova';
$strRowsStatistic = 'Statistike reda';
$strRunning = 'na serveru %s';
$strRunQuery = 'Izvrši SQL upit';
$strRunSQLQuery = 'Izvrši SQL upit(e) na bazi %s';
$strRussian = 'Ruski';

$strSaveOnServer = 'Sačuvaj na server u direktorijum %s';
$strSave = 'Sačuvaj';
$strScaleFactorSmall = 'Faktor umanjenja je premali da bi shema stala na jednu stranu';
$strSearchFormTitle = 'Pretraživanje baze';
$strSearchInTables = 'Unutar tabela:';
$strSearchNeedle = 'Reči ili vrednosti koje se traže (džoker: "%"):';
$strSearchOption1 = 'bar jednu od reči';
$strSearchOption2 = 'sve reči';
$strSearchOption3 = 'tačan izraz';
$strSearchOption4 = 'kao regularni izraz';
$strSearch = 'Pretraživanje';
$strSearchResultsFor = 'Rezultati pretrage za "<i>%s</i>" %s:';
$strSearchType = 'Traži:';
$strSecretRequired = 'Konfiguraciona datoteka zahteva tajnu lozinku (blowfish_secret).';
$strSelectADb = 'Izaberite bazu';
$strSelectAll = 'Izaberi sve';
$strSelectBinaryLog = 'Izaberite binarni dnevnik za pregled';
$strSelectFields = 'Izaberi polja (najmanje jedno)';
$strSelectNumRows = 'u upitu';
$strSelectTables = 'Izaberi tabele';
$strSend = 'Sačuvaj kao datoteku';
$strSent = 'Poslato';
$strServerChoice = 'Izbor servera';
$strServerNotResponding = 'Server ne odgovara';
$strServer = 'Server';
$strServerStatus = 'Informacije o toku rada';
$strServerStatusUptime = 'Ovaj MySQL server radi već %s. Pokrenut je %s.';
$strServerTabVariables = 'Promenljive';
$strServerTrafficNotes = '<b>Saobraćaj servera</b>: Tabele pokazuju statistike mrežnog saobraćaja na ovom MySQL serveru od njegovog pokretanja.';
$strServerVars = 'Serverske promenljive i podešavanja';
$strServerVersion = 'Verzija servera';
$strSessionValue = 'Vrednost sesije';
$strSetEnumVal = 'Ako je polje "enum" ili "set", unesite vrednosti u formatu: \'a\',\'b\',\'c\'...<br />Ako vam treba obrnuta kosa crta ("\\") ili apostrof ("\'") koristite ih u "izbegnutom" (escaped) obliku (na primer \'\\\\xyz\' ili \'a\\\'b\').';
$strShowAll = 'Prikaži sve';
$strShowColor = 'Prikaži boju';
$strShowDatadictAs = 'Format rečnika podataka';
$strShowFullQueries = 'Prikaži kompletne upite';
$strShowGrid = 'Prikaži mrežu';
$strShowingRecords = 'Prikaz zapisa';
$strShowPHPInfo = 'Prikaži informacije o PHP-u';
$strShow = 'Prikaži';
$strShowTableDimension = 'Prikaži dimenzije tabele';
$strShowTables = 'Prikaži tabele';
$strShowThisQuery = 'Prikaži ponovo ovaj upit';
$strSimplifiedChinese = 'Pojednostavljeni kineski';
$strSingly = '(po jednom polju)';
$strSize = 'Veličina';
$strSlovak = 'Slovački';
$strSlovenian = 'Slovenački';
$strSocketProblem = '(ili priključak lokalnog MySQL servera nije ispravno podešen)';
$strSortByKey = 'Sortiraj po ključu';
$strSort = 'Sortiranje';
$strSpaceUsage = 'Zauzeće';
$strSpanish = 'Španski';
$strSplitWordsWithSpace = 'Reči se odvajaju razmakom (" ").';
$strSQLExportType = 'Tip izvoza';
$strSQLParserBugMessage = 'Postoji mogućnost da ste pronašli bag u SQL parseru. Molimo ispitajte svoj upit pažljivo, i proverite da su navodnici ispravni i da ne nedostaju. Ostali mogući razlozi greške mogu biti da ste poslali binarnu datoteku van oblasti za običan tekst. Možete probati svoj upit u MySQL sučelju komandne linije. Donja poruka o grešci MySQL servera, ako je ima, može vam pomoći u otkrivanju problema. Ako i dalje imate probleme ili ako parser ne uspeva tamo gde uspeva sučelje komandne linije, svedite svoj SQL upit na jedan jedini upit koji stvara probleme i pošaljite nam izveštaj o grešci sa delom koda u donjoj REZ sekciji:';
$strSQLParserUserError = 'Izgleda da postoji greška u vašem SQL upitu. Ovde je poruka o greški MySQL servera, koja vam može pomoći u otkrivanju problema';
$strSQLQuery = 'SQL upit';
$strSQLResult = 'SQL rezultat';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Neispravan identifikator';
$strSQPBugUnclosedQuote = 'Navodnik nije zatvoren';
$strSQPBugUnknownPunctuation = 'Nepoznat string interpunkcije';
$strStatCheckTime = 'Poslednja provera';
$strStatCreateTime = 'Napravljeno';
$strStatement = 'Ime';
$strStatUpdateTime = 'Poslednja izmena';
$strStatus = 'Status';
$strStorageEngine = 'Pogon skladištenja';
$strStorageEngines = 'Pogoni skladištenja';
$strStrucCSV = 'CSV format';
$strStrucData = 'Struktura i podaci';
$strStrucExcelCSV = 'CSV za MS Excel';
$strStrucNativeExcel = 'Izvorni MS Excel podaci';
$strStrucOnly = 'Samo struktura';
$strStructPropose = 'Predloži strukturu tabele';
$strStructure = 'Struktura';
$strSubmit = 'Pošalji';
$strSuccess = 'Vaš SQL upit je uspešno izvršen';
$strSum = 'Ukupno';
$strSwedish = 'Švedski';
$strSwitchToDatabase = 'Prebaci se na kopiranu bazu';
$strSwitchToTable = 'Pređi na kopiranu tabelu';

$strTableComments = 'Komentari tabele';
$strTableEmpty = 'Ima tabele je prazno!';
$strTableHasBeenDropped = 'Tabela %s je odbačena';
$strTableHasBeenEmptied = 'Tabela %s je ispražnjena';
$strTableHasBeenFlushed = 'Tabela %s je osvežena';
$strTableMaintenance = 'Radnje na tabeli';
$strTableOfContents = 'Sadržaj';
$strTableOptions = 'Opcije tabele';
$strTables = '%s tabela';
$strTableStructure = 'Struktura tabele';
$strTable = 'Tabela';
$strTakeIt = 'preuzmi';
$strTblPrivileges = 'Privilegije vezane za tabele';
$strTextAreaLength = 'Zbog njehove veličine, polje<br />možda nećete moći da izmenite';
$strThai = 'Tajski';
$strTheme = 'Tema / stil';
$strThisHost = 'Ovaj server';
$strThreadSuccessfullyKilled = 'Proces %s je uspešno prekinut.';
$strTime = 'Vreme';
$strToggleScratchboard = 'Uključi/isključi radnu tablu';
$strTotalUC = 'Ukupno';
$strTotal = 'ukupno';
$strTraditionalChinese = 'Tradicionalni kineski';
$strTraditionalSpanish = 'Tradicionalni španski';
$strTraffic = 'Saobraćaj';
$strTransformation_application_octetstream__download = 'Prikazuje vezu za preuzimanje binarnih podataka za polje. Prva opcija je ime binarne datoteke. Druga opcija je moguće ime polja reda tabele koji sadrži ime datoteke. Ako date drugu opciju, prva mora biti postavljena na prazan string';
$strTransformation_application_octetstream__hex = 'Prikazuje heksadecimalni prikaz podataka. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
$strTransformation_image_jpeg__inline = 'Prikazuje umanjenu sliku na koju je moguće kliknuti; opcije: širina, visina u pikselima (čuva originalni odnos)';
$strTransformation_image_jpeg__link = 'Prikazuje link ka ovoj slici (npr. direktno preuzimanje iz BLOB-a).';
$strTransformation_image_png__inline = 'Prikaži JPEG slike na strani';
$strTransformation_text_plain__external = 'SAMO LINUX: Pokreće eksternu aplikaciju i popunjava podatke u poljima preko standardnog ulaza. Vraća standardni izlaz aplikacije. Podrazumevano je Tidy, za lepši prikaz HTML koda. Zbog sigurnosnih razloga, morate ručno izmeniti datoteku libraries/transformations/text_plain__external.inc.php i dodati alate koje želite da koristite. Prva opcija je broj programa koje želite da koristite, a druga su parametri programa. Ako se treći parametar postavi na 1 izlaz će biti konvertovan koristeći htmlspecialchars() (podrazumevano je 1). Ako je četvrti parametar postavljen na 1, NOWRAP će biti dodato ćeliji sa sadržajem tako da će izlaz biti prikazan bez izmena. (podrazumevano 1)';
$strTransformation_text_plain__formatted = 'Čuva originalno formatiranje polja. Escaping se ne vrši.';
$strTransformation_text_plain__imagelink = 'Prikazuje sliku i link, polje sadrži naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je širina u pikselima, treća je visina.';
$strTransformation_text_plain__link = 'Prikazuje link, polje sadrži naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je naslov za link.';
$strTransformation_text_plain__substr = 'Pokazuje deo stringa. Prva opcija je broj znakova koje treba preskočiti od početka stringa (podrazumevano 0). Druga opcija je broj vraćenih znakova (podrazumevano: do kraja stringa). Treća opcija je string koji se dodaje kada dođe do odsecanja (podrazumevano: ...) .';
$strTruncateQueries = 'Prikaži skraćene upite';
$strTurkish = 'Turski';
$strType = 'Tip';

$strUkrainian = 'Ukrajinski';
$strUncheckAll = 'nijedno';
$strUnicode = 'Unikod';
$strUnique = 'Jedinstveni';
$strUnknown = 'nepoznat';
$strUnselectAll = 'ništa';
$strUpdatePrivMessage = 'Ažurirali ste privilegije za %s.';
$strUpdateProfileMessage = 'Profil je promenjen.';
$strUpdateQuery = 'Ažuriraj upit';
$strUpdComTab = 'Molimo pogledajte u dokumentaciji kako se ažurira tabela Column_comments';
$strUpgrade = 'Trebalo bi da unapredite vaš %s server na verziju %s ili noviju.';
$strUsage = 'Zauzeće';
$strUseBackquotes = 'Koristi \' za ograničavanje imena polja';
$strUseHostTable = 'Koristi tabelu domaćina';
$strUserAlreadyExists = 'Korisnik %s već postoji!';
$strUserEmpty = 'Ime korisnika nije uneto!';
$strUser = 'Korisnik';
$strUserName = 'Ime korisnika';
$strUserNotFound = 'Izabrani korisnik nije pronađen u tabeli privilegija.';
$strUserOverview = 'Pregled korisnika';
$strUsersDeleted = 'Izabrani korisnici su uspešno obrisani.';
$strUsersHavingAccessToDb = 'Korisnici koji imaju pristup &quot;%s&quot;';
$strUseTabKey = 'Koristite TAB taster za pomeranje od polja do polja, ili CTRL+strelice za slobodno pomeranje';
$strUseTables = 'Koristi tabele';
$strUseTextField = 'Koristi tekst polje';
$strUseThisValue = 'Koristi ovu vrednost';

$strValidateSQL = 'Proveri SQL';
$strValidatorError = 'SQL validator nije mogao da bude pokrenut. Proverite da li su instalirane neophodne PHP ekstenzije opisane u  %sdokumentaciji%s.';
$strValue = 'Vrednost';
$strVar = 'Promenljiva';
$strVersionInformation = 'Informacije o verziji';
$strViewDumpDatabases = 'Prikaži sadržaj (shemu) baze';
$strViewDumpDB = 'Prikaži sadržaj (shemu) baze';
$strViewDump = 'Prikaži sadržaj (shemu) tabele';
$strViewHasBeenDropped = 'Pogled %s je odbačen';
$strView = 'Pogled';

$strWebServerUploadDirectory = 'direktorijum za slanje veb servera ';
$strWebServerUploadDirectoryError = 'Direktorijum koji ste izabrali za slanje nije dostupan';
$strWelcome = 'Dobrodošli na %s';
$strWestEuropean = 'Zapadnoevropski';
$strWildcard = 'džoker';
$strWindowNotFound = 'Odredišni prozor pretraživača nije mogao da bude ažuriran. Možda ste zatvorili matični prozor, ili vaš pretraživač onemogućava ažuriranje među prozorima zbog sigurnosnih podešavanja';
$strWithChecked = 'Označeno:';
$strWriteRequests = 'Zahtevi za upis';
$strWrongUser = 'Pogrešno korisničko ime/lozinka. Pristup odbijen.';

$strXML = 'XML';

$strYes = 'Da';

$strZeroRemovesTheLimit = 'Napomena: Postavljanje ovih opcija na 0 (nulu) uklanja ograničenja.';
$strZip = '"zipovano"';

// To translate:
$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate

$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strBrowseDistinctValues = 'Browse distinct values';  //to translate

$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
$strCSV = 'CSV';  //to translate

$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate

$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strEsperanto = 'Esperanto';  //to translate

$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
$strFileNameTemplateDescriptionServer = 'server name';  //to translate
$strFileNameTemplateDescriptionTable = 'table name';  //to translate
$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strFileToImport = 'File to import';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate

$strHandler = 'Handler';  //to translate

$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strImport = 'Import';  //to translate
$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate

$strJoins = 'Joins';  //to translate

$strKeyCache = 'Key cache';  //to translate

$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate

$strMaxConnects = 'max. concurrent connections';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strMysqlClientVersion = 'MySQL client version';  //to translate

$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate

$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate

$strPartialImport = 'Partial import';  //to translate
$strPDF = 'PDF';  //to translate
$strPDFReportTitle = 'Report title';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strProtocolVersion = 'Protocol version';  //to translate

$strQueryCache = 'Query cache';  //to translate

$strReloadPrivileges = 'Reload privileges';  //to translate
$strReplication = 'Replication';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate

$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strSorting = 'Sorting';  //to translate
$strSQLCompatibility = 'SQL compatibility mode';  //to translate
$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate

$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
$strThemeNotFound = 'Theme %s not found!';  //to translate
$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
$strThreads = 'Threads';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate

$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strUsedPhpExtensions = 'Used PHP extensions';  //to translate

$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate

$strQueryResultsOperations = 'Query results operations';  //to translate
$strAddClause = 'Add %s';  //to translate
$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
$strCreateUserDatabase = 'Database for user';  //to translate
$strCreateUserDatabaseNone = 'None';  //to translate
$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
$strOpenDocumentText = 'Open Document Text';  //to translate
$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
$strInvalidTableName = 'Invalid table name';  //to translate
$strInvalidDatabase = 'Invalid database';  //to translate
$strServers = 'Servers';  //to translate
$strDelimiter = 'Delimiter';  //to translate
$strFunctions = 'Functions';  //to translate
$strProcedures = 'Procedures';  //to translate
$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
$strFontSize = 'Font size';  //to translate
$strLanguage = 'Language';  //to translate
$strPmaWiki = 'phpMyAdmin wiki';  //to translate
$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
$strDocSQL = 'DocSQL';  //to translate
$strTableName = 'Table name';  //to translate
$strTableIsEmpty = 'Table seems to be empty!';  //to translate
$strDbIsEmpty = 'Database seems to be empty!';  //to translate
$strShowingPhp = 'Showing as PHP code';  //to translate
$strShowingSQL = 'Showing SQL query';  //to translate
$strDesigner = 'Designer';  //to translate
$strNumberOfTables = 'Number of tables';  //to translate
$strCreateTable  = 'Create table';  //to translate
$strCreateRelation = 'Create relation';  //to translate
$strSavePosition = 'Save position';  //to translate
$strSelectForeignKey = 'Select Foreign Key';  //to translate
$strHide         = 'Hide';  //to translate
$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
$strReload = 'Reload';  //to translate
$strSmallBigAll = 'Small/Big All';  //to translate
$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
$strMoveMenu = 'Move Menu';  //to translate
$strAngularLinks = 'Angular links';  //to translate
$strDirectLinks = 'Direct links';  //to translate
$strHideShowAll = 'Hide/Show all';  //to translate
$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
$strInternalRelationAdded = 'Internal relation added';  //to translate
$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
$strRelationDeleted = 'Relation deleted';  //to translate
$strToSelectRelation = 'To select relation, click :';  //to translate
$strExportImportToScale = 'Export/Import to scale';  //to translate
$strRecommended = 'recommended';  //to translate
$strToFromPage = 'to/from page';  //to translate
$strSelectReferencedKey = 'Select referenced key';  //to translate
$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
$strHelp = 'Help';  //to translate
$strCancel = 'Cancel';  //to translate
$strDeleteRelation = 'Delete relation';  //to translate
$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
$strStructureForView = 'Structure for view';  //to translate
$strStandInStructureForView = 'Stand-in structure for view';  //to translate
$strToggleSmallBig = 'Toggle small/big';  //to translate
$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
$strViewName = 'VIEW name';  //to translate
$strOptions = 'Options';  //to translate
$strFiles = 'Files';  //to translate
$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
$strRoutines = 'Routines';  //to translate
$strRoutineReturnType = 'Return type';  //to translate
$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
$strTriggers = 'Triggers';  //to translate
$strEvent = 'Event';  //to translate
$strProfiling = 'Profiling';  //to translate
?>
